Your message dated Mon, 18 Jan 2016 17:22:52 +0000
with message-id <[email protected]>
and subject line Bug#697002: fixed in sysvinit 2.88dsf-59.3
has caused the Debian Bug report #697002,
regarding use fsck -M instead of fsck -R
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
697002: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=697002
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: util-linux
Version: 2.20.1-5.3
Severity: important
Tags: patch
Usertags: usrinitramfs etcinitramfs
The attached patch is to apply for jessie, so isn't appropriate
to use until after wheezy is released. See
http://wiki.debian.org/ReleaseGoals/MountUsrInInitramfs
for further information.
To summarise, the intent is to mount /usr (and potentially also
/etc for certain specialised use cases) in the initramfs, so that
/usr is available as soon as init starts.
The fsck -R option ignores filesystems which are mounted when
checkfs runs. Currently this is only the rootfs (plus special
filesystems which aren't checked). With /usr (and /etc) mounted
early, the -R option therefore needs extending to support these
filesystems as well so that we check them manually in checkroot,
and skip them in checkfs.
The upload of this change will need coordinating with the
initramfs-tools and sysvinit packages so that we get the
dependencies correct so that usr is checked (and only checked
once, not zero or twice).
Thanks,
Roger
-- System Information:
Debian Release: wheezy/sid
APT prefers testing
APT policy: (500, 'testing')
Architecture: i386 (i686)
Kernel: Linux 2.6.32.33-kvm-i386-20111128-dirty (SMP w/1 CPU core)
Locale: LANG=en_GB.UTF-8, LC_CTYPE=en_GB.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
Versions of packages util-linux depends on:
ii debconf [debconf-2.0] 1.5.48
ii dpkg 1.16.9
ii initscripts 2.88dsf-34
ii install-info 4.13a.dfsg.1-10
ii libblkid1 2.20.1-5.3
ii libc6 2.13-37
ii libncurses5 5.9-10
ii libselinux1 2.1.9-5
ii libslang2 2.2.4-15
ii libtinfo5 5.9-10
ii libuuid1 2.20.1-5.3
ii lsb-base 4.1+Debian8
ii tzdata 2012j-1
ii zlib1g 1:1.2.7.dfsg-13
util-linux recommends no packages.
Versions of packages util-linux suggests:
pn dosfstools <none>
pn kbd | console-tools <none>
pn util-linux-locales <none>
-- debconf information excluded
--- util-linux-2.20.1.original/fsck/fsck.8 2012-12-25 15:14:40.000000000 +0000
+++ util-linux-2.20.1/fsck/fsck.8 2012-12-27 22:19:18.000000000 +0000
@@ -273,8 +273,8 @@
.B \-R
When checking all filesystems with the
.B \-A
-flag, skip the root filesystem. (This is useful in case the root
-filesystem has already been mounted read-write.)
+flag, skip the root, /etc and /usr filesystems. (This is useful in case the root,
+/etc and/or /usr filesystems have already been mounted read-write.)
.TP
.B \-T
Don't show the title on startup.
--- util-linux-2.20.1.original/fsck/fsck.c 2012-12-25 15:14:40.000000000 +0000
+++ util-linux-2.20.1/fsck/fsck.c 2012-12-27 22:18:20.000000000 +0000
@@ -1132,11 +1132,11 @@
}
/*
* This is for the bone-headed user who enters the root
* filesystem twice. Skip root will skep all root entries.
*/
if (skip_root)
for (fs = filesys_info; fs; fs = fs->next)
- if (!strcmp(fs->mountpt, "/"))
+ if (!strcmp(fs->mountpt, "/") || !strcmp(fs->mountpt, "/etc") || !strcmp(fs->mountpt, "/usr"))
fs->flags |= FLAG_DONE;
while (not_done_yet) {
--- End Message ---
--- Begin Message ---
Source: sysvinit
Source-Version: 2.88dsf-59.3
We believe that the bug you reported is fixed in the latest version of
sysvinit, which is due to be installed in the Debian FTP archive.
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Ben Hutchings <[email protected]> (supplier of updated sysvinit package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512
Format: 1.8
Date: Mon, 18 Jan 2016 14:39:32 +0000
Source: sysvinit
Binary: sysvinit sysvinit-core sysvinit-utils sysv-rc initscripts bootlogd
Architecture: source
Version: 2.88dsf-59.3
Distribution: unstable
Urgency: medium
Maintainer: Debian sysvinit maintainers
<[email protected]>
Changed-By: Ben Hutchings <[email protected]>
Description:
bootlogd - daemon to log boot messages
initscripts - scripts for initializing and shutting down the system
sysv-rc - System-V-like runlevel change mechanism
sysvinit - System-V-like init utilities - transitional package
sysvinit-core - System-V-like init utilities
sysvinit-utils - System-V-like utilities
Closes: 697002 798406 805487
Changes:
sysvinit (2.88dsf-59.3) unstable; urgency=medium
.
* Non-maintainer upload.
.
[ Samuel Thibault ]
* /etc/init.d/rc: Mount /proc on GNU/Hurd too (Closes: #798406)
.
[ Ben Hutchings ]
* Add support for mount and fsck of root and /usr by an initramfs:
- checkroot.sh: Do nothing if /run/initramfs/fsck-root exists
- checkfs.sh: Pass -M option to fsck instead of -R (Closes: #697002)
- mountall.sh: Remount /usr if already mounted
* Remove current uploaders, all of which have retired
.
[ Andreas Henriksson ]
* Move service control commands to init-system-helpers (Closes: #805487)
- sysv-rc: Drop invoke-rc.d + update-rc.d
- sysvinit-utils: Drop service
- sysv-rc/sysvinit-utils: (Pre-)Depends on init-system-helpers
- sysv-rc: drop now obsolete Conflicts/Replaces file-rc
Checksums-Sha1:
b1c160f1ab3c01253779adeb438a7c41766e2bea 2286 sysvinit_2.88dsf-59.3.dsc
51e3395c985a3b08ad0de6a6313135fea8ba7945 132476
sysvinit_2.88dsf-59.3.debian.tar.xz
Checksums-Sha256:
9922dbcd0ac7e646fae0db52358b1e6d1749eb2b6292bcfd3b0913459c51385d 2286
sysvinit_2.88dsf-59.3.dsc
05e6fa51651ad79f36b18c8dd2418549a12cd21726dc9a42219908d07d687e7d 132476
sysvinit_2.88dsf-59.3.debian.tar.xz
Files:
d991436eb81198aaa2927b6442b9370b 2286 admin required sysvinit_2.88dsf-59.3.dsc
43cf8456a4a55f6436102c05f358a693 132476 admin required
sysvinit_2.88dsf-59.3.debian.tar.xz
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1
iQIVAwUBVp0ZMee/yOyVhhEJAQrMFw//TB7RZGH2bKHGrx3RFwRzf7idSPpbo6JL
FAbwJRMvSx/69LVAxbqw7dfKGIeA8Z5GX1aiHJ5i1yxpYhzymwl803LocqNDi57+
DMK2qfO1cG5XWKcCcFEVyPZMClrGtbKH7DaPoHTVjfJmfa9cL1v0hJxSDfCeOZu5
04hDFFF7a7byKvZav3KFTF5BElQDcbtMpDLhj7Lcsm69ih7zhgn8ZtICtBqRFrJt
H4vDc0+28RPvDV9RR6ih4pRXt3V2sjKV0X1x5bR+cSyYKc4ojHNTDCQxJrNuCTln
zrgFs7DwRrkaPkzXbIIMPG5Pv7aTNoZwzrZgf+ffTNYgVNczTjwD7EJCq42w3/p0
vJ/5gH1dSwG99jiJ3lQO0gL1BX3xq0GUmNVW7N0v1XQSPZ2ZW2JtUS56ZwLEDXVs
Z4eppFhnS2kcPFUIApMQELloz436wvynVJifp8xi9iNY3MLdCHlxX93/FTi9vMwy
o+2+ZpZW+DsBh9nG5S/tZTOBAh6hlT75GDZNPrTPvP8L7WSZJEqCAvml6FPsp2Go
3KoGXwNq5fqGASU2lVkiawHs2qdgAkS1K8jX+8TGuTv/PHdj9TXDxCtUnYm6/6TD
54yUCEL/csFfLi3bv+Uq2+DCx9qxm4qHcj9x4MxSYY+VPgRp0Y/ke7JOu7iPLoLk
DqiDQWr7MKQ=
=Gxhz
-----END PGP SIGNATURE-----
--- End Message ---
_______________________________________________
Pkg-sysvinit-devel mailing list
[email protected]
@@ -1132,11 +1132,11 @@
/*
* This is for the bone-headed user who enters the root
- * filesystem twice. Skip root will skep all root entries.
+ * filesystem twice. Skip root will skep all root, /etc and /usr entries.
*/
if (skip_root)
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-sysvinit-devel